function [Mzd,J]  = calc_relative_M_z(Mzp)
%% calculate uncertain relative motion M12 = inv(M1) * M2
%  partially exponential representation
%
% Mzp   rotation pair, Mzp.Mzp=[M1,M2]=[4,8], Mzp.Czp = [12x12]
%
% Mzd   relative rotation, Mzd.Mz=[4x4], Mzd.Cz=[6x6]
% J     [6x12] Jacobian
%
% wf 6/2020

% M1, M2, M12
Mz1    = Mzp.Mzp(:,1:4);
Mz2    = Mzp.Mzp(:,5:8);
Mzd.Mz = inv(Mz1) * Mz2;

% Jacobian
R1     = Mz1(1:3,1:3);
Z1     = Mz1(1:3,4);
Z2     = Mz2(1:3,4);
J      =  [-R1'                zeros(3)  R1'       zeros(3);...
            R1'*calc_S(Z2-Z1)  -R1'      zeros(3)   R1'    ];
% CovM
Mzd.Cz = J * Mzp.Czp * J';

return
